# Generated by Django 5.0.4 on 2024-04-16 11:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('advance', '0011_rename_account_global_api_key_cloudflare_api_global_api_key'),
    ]

    operations = [
        migrations.AddField(
            model_name='cloudflare_api',
            name='ip_address',
            field=models.GenericIPAddressField(default='127.0.0.1'),
        ),
        migrations.AddField(
            model_name='cloudflare_api',
            name='ip_address2',
            field=models.GenericIPAddressField(default='127.0.0.2'),
        ),
    ]
