{% extends 'base.html' %}
{%block title %} bigsansar - login {% endblock %}
{% block head %}
{% load static %}
<link rel="stylesheet" href="{% static 'style.css' %}">
{% endblock %}
{% block body %}
{% include 'admin/nav.html' %}


<!-- for description-->

{% if messages %}
    <ul class="messages">
        {% for message in messages %}
            <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message }}</li>
        {% endfor %}
    </ul>
{% endif %}


<div class="wrapper">
    <form class="form" method="post" action="" >
        <h2 class="form-heading text-center">Login</h2><br/>
        {% csrf_token %}
        {{form.as_p}}
        <p class="text-center"><a href="/lostpass">Forget Password?</a></p>
        <p class="text-center"><button type="submit" class="btn btn-lg btn-primary btn-block">Login</button>
        <!-- <a class="btn btn-lg btn-dark btn-block" href="/signup" role="button">Sign Up</a></p> -->

    </form>
</div>
{% endblock %}