# Generated by Django 5.0.2 on 2024-02-12 05:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_default_domain'),
    ]

    operations = [
        migrations.AddField(
            model_name='domains',
            name='default',
            field=models.BooleanField(default='False'),
        ),
    ]
