# Generated by Django 5.0.4 on 2024-05-09 10:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0010_alter_domains_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='domains',
            name='zone_id',
            field=models.CharField(default='', max_length=1000),
        ),
    ]
