# Generated by Django 4.2 on 2023-06-18 11:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('advance', '0004_alter_javascript_options'),
    ]

    operations = [
        migrations.DeleteModel(
            name='css',
        ),
    ]
