# Generated by Django 5.0.4 on 2024-04-13 11:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('advance', '0010_cloudflare_api'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cloudflare_api',
            old_name='account_global_api_key',
            new_name='global_api_key',
        ),
    ]
