# Generated by Django 4.2 on 2023-05-13 03:08

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('advance', '0002_alter_css_options'),
    ]

    operations = [
        migrations.CreateModel(
            name='javascript',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('javascript', models.TextField()),
                ('domain', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='sites.domains')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'Javascripts',
                'verbose_name_plural': 'Javascripts',
            },
        ),
    ]
