# Generated by Django 5.0.2 on 2024-02-12 05:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0003_domains_default'),
    ]

    operations = [
        migrations.AlterField(
            model_name='domains',
            name='default',
            field=models.BooleanField(default=False),
        ),
    ]
