{% extends 'base.html' %}
{%block title %} bigsansar - Cloudflare configrations {% endblock %}
{% block head %}
{% load static %}
<link rel="stylesheet" href="{% static 'style.css' %}">
{% endblock %}
{% block body %}
{% include 'admin/nav.html' %}

<style>
    .info-box {
        background-color: #f8f9fa;
        padding: 20px;
        border: 1px solid #ccc;
        border-radius: 5px;
        margin: 20px auto;
        max-width: 400px;
        text-align: center;
    }

    
</style>
</head>
<body>
    
   

<div id="info-box" class="info-box">
    {% if messages %}
		{% for message in messages %}
		{% if message.tags %}
		<div class="alert alert-{{ message.tags }} alert-dismissible fade show" role="alert">
			{{ message }}
			<button type="button" class="btn-close" data-bs-dismiss="alert" aria-label="Close">
			</button>
		</div>
		{% endif %}
		{% endfor %}
		{% endif %}
    {% if status == 'pending' %}
    <div class="card">
        <div class="card-header">
            {{ cf.main_domain_name }} is not active on Cloudflare yet
        </div>
        <div class="card-body">
            <p class="card-text">
                Your assigned Cloudflare nameservers:
                <ul>
            <li>{{ name_servers1 }}</li>
            <li>{{ name_servers2 }}</li>
        </ul>
            </p>
        </div>
    </div>
    {% else %}
    
    
    {% if ssl_value == 'strict' %}
    <svg xmlns="http://www.w3.org/2000/svg" class="d-none">
        <symbol id="check-circle-fill" viewBox="0 0 16 16">
          <path d="M16 8A8 8 0 1 1 0 8a8 8 0 0 1 16 0zm-3.97-3.03a.75.75 0 0 0-1.08.022L7.477 9.417 5.384 7.323a.75.75 0 0 0-1.06 1.06L6.97 11.03a.75.75 0 0 0 1.079-.02l3.992-4.99a.75.75 0 0 0-.01-1.05z"/>
        </symbol>
        <symbol id="info-fill" viewBox="0 0 16 16">
          <path d="M8 16A8 8 0 1 0 8 0a8 8 0 0 0 0 16zm.93-9.412-1 4.705c-.07.34.029.533.304.533.194 0 .487-.07.686-.246l-.088.416c-.287.346-.92.598-1.465.598-.703 0-1.002-.422-.808-1.319l.738-3.468c.064-.293.006-.399-.287-.47l-.451-.081.082-.381 2.29-.287zM8 5.5a1 1 0 1 1 0-2 1 1 0 0 1 0 2z"/>
        </symbol>
        <symbol id="exclamation-triangle-fill" viewBox="0 0 16 16">
          <path d="M8.982 1.566a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566zM8 5c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 5.995A.905.905 0 0 1 8 5zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>
        </symbol>
      </svg>
    <div class="alert alert-success d-flex align-items-center" role="alert">
        <svg class="bi flex-shrink-0 me-2" width="24" height="24" role="img" aria-label="Success:"><use xlink:href="#check-circle-fill"/></svg>
        <div>
            Your SSL/TLS encryption mode is Full (strict)
        </div>
      </div>
    {% else %}
    <div class="alert alert-danger d-flex align-items-center" role="alert">
        <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" fill="currentColor" class="bi bi-exclamation-triangle-fill flex-shrink-0 me-2" viewBox="0 0 16 16" role="img" aria-label="Warning:">
          <path d="M8.982 1.566a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566zM8 5c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 5.995A.905.905 0 0 1 8 5zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"/>
        </svg>
        <div>
    Encrypts end-to-end, but requires a trusted CA or Cloudflare Origin CA certificate on the server. <a href="/admin/cf/ssl_origin">Setup</a> encryption of traffic between your origin server and Cloudflare.
        </div>
    </div>
    {% endif %}
    {% endif %}
   
    <br/>
    <br/>
    <div class="row">
        <div class="col-sm-3">
            <h6 class="mb-0">Email</h6>
        </div>
        <div class="col-sm-9 text-secondary">
            {{ cf.email }}
        </div>
    </div>
    <hr>
    <div class="row">
        <div class="col-sm-3">
            <h6 class="mb-0"> Domain </h6>
        </div>
        <div class="col-sm-9 text-secondary">
            {{ cf.main_domain_name }}
        </div>
        
    </div>
    <hr>
    <div class="row">
        <div class="col-sm-3">
            <h6 class="mb-0"> Ip Address </h6>
        </div>
        <div class="col-sm-9 text-secondary">
            {{ cf.ip_address }}
        </div>
        
    </div>
    <hr>
    <div class="row">
        <div class="col-sm-3">
            <h6 class="mb-0"> Ip Address 2 </h6>
        </div>
        <div class="col-sm-9 text-secondary">
            {{ cf.ip_address2 }}
        </div>
        
    </div>
    <hr>
   <br/>
   <a class="btn btn-primary" href="/admin/cf/api_key" role="button">Link to Cloudflare</a>
</div>



{% endblock %}