# Generated by Django 5.0.2 on 2024-03-17 14:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('advance', '0007_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='SidebarSettings',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_sidebar_open', models.BooleanField(default=True)),
            ],
        ),
    ]
