# Generated by Django 5.0.2 on 2024-02-12 05:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0004_alter_domains_default'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='domains',
            name='default',
        ),
    ]
