CKEDITOR.plugins.setLang('youtube', 'fr', {
	button : 'Insérer une vidéo Youtube',
	title : 'Insérer une vidéo youtube',
	txtEmbed : 'Coller le code embed ici',
	txtUrl : 'Coller l\'url de la vidéo ici',
	txtWidth : 'Largeur',
	txtHeight : 'Hauteur',
	chkRelated : 'Montrer les suggestions de vidéo à la fin',
	txtStartAt : 'Commencer à (ss ou mm:ss ou hh:mm:ss)',
	chkPrivacy : 'Activer la protection de la vie privée',
	chkOlderCode : 'Utiliser l\'ancien code embed',
	chkAutoplay : 'Autoplay',
	chkControls : 'Afficher les commandes du lecteur',
	noCode : 'Vous devez entrer un code embed ou une url',
	invalidEmbed : 'Le code embed est invalide',
	invalidUrl : 'L\'url est invalide',
	or : 'ou',
	noWidth : 'Vous devez saisir une largeur',
	invalidWidth : 'La largeur saisie est invalide',
	noHeight : 'Vous devez saisir une hauteur',
	invalidHeight : 'La hauteur saisie est invalide',
	invalidTime : 'Le temps de départ de la vidéo est invalide',
	txtResponsive : 'Responsive video',
	txtNoEmbed : 'Vidéo image et lien seulement'
});
